@@ -1,7 +1,7 @@
 import importlib.util
 import sys
 
-spec = importlib.util.spec_from_file_location("libtpu", "/usr/lib/libtpu.so")
+spec = importlib.util.spec_from_file_location("libtpu", "/usr/lib/pytpu.so")
 assert spec
 libtpu = importlib.util.module_from_spec(spec)
 sys.modules['pytpu.pytpu'] = libtpu
